#include <WiFiNINA.h>

char ssid[] = "Arduino_Server";
char pass[] = "12345678";
char serverIP[] = "192.168.4.1";
int serverPort = 80;

WiFiClient client;
String nombreCliente = "Cono_1"; // Cambiar en cada Arduino
bool conectadoOK = false;

const int ledPin = LED_BUILTIN;

void setup() {
  Serial.begin(115200);
  pinMode(ledPin, OUTPUT);
  digitalWrite(ledPin, LOW);

  Serial.println("🔄 Cliente iniciando...");

  while (WiFi.begin(ssid, pass) != WL_CONNECTED) {
    Serial.print(".");
    delay(1000);
  }

  Serial.println("\n✅ Conectado al AP");

  conectarAlServidor();
}

void loop() {
  if (!client.connected()) {
    Serial.println("❌ Perdida conexión. Reintentando...");
    conectadoOK = false;
    conectarAlServidor();
  }

  if (client.available()) {
    String mensaje = client.readStringUntil('\n');
    mensaje.trim();
    Serial.print("📩 Mensaje del servidor: ");
    Serial.println(mensaje);

    if (mensaje == "LED_ON") {
      digitalWrite(ledPin, HIGH);
      Serial.println("💡 LED ENCENDIDO");
    } else if (mensaje == "LED_OFF") {
      digitalWrite(ledPin, LOW);
      Serial.println("💡 LED APAGADO");
    }
  }

  if (conectadoOK) {
    client.println("SIGO AQUI: " + nombreCliente);
  }

  delay(5000);
}

void conectarAlServidor() {
  while (!client.connect(serverIP, serverPort)) {
    Serial.print(".");
    delay(1000);
  }

  Serial.println("\n✅ Conectado al servidor");

  client.println("NOMBRE:" + nombreCliente);

  unsigned long timeout = millis();
  while (!client.available() && millis() - timeout < 5000) {
    delay(100);
  }

  if (client.available()) {
    String respuesta = client.readStringUntil('\n');
    if (respuesta == "ID_CONFIRMADO") {
      Serial.println("🆔 ID confirmado por el servidor");
      conectadoOK = true;
    } else if (respuesta == "DUPLICADO") {
      Serial.println("❌ Nombre ya en uso. Desconectado.");
      client.stop();
      conectadoOK = false;
    }
  }
}